@@ -1,13 +1,13 @@
 """Exceptions for ``clinvar-tsv``."""
 
 
-class ClinvarTsvException(Exception):
+class ClinvarTsvException(Exception):  # pragma: no cover
     """Exception raised by ``clinvar-tsv``"""
 
 
-class XmlParseException(Exception):
+class XmlParseException(Exception):  # pragma: no cover
     """Raised on problems parsing the XML"""
 
 
-class NoSequenceLocation(Exception):
+class NoSequenceLocation(Exception):  # pragma: no cover
     """Raised on problems parsing the XML"""
